pub struct HostFunctionPolicy { /* private fields */ }Expand description
Host function policy used before running a WASM capability.
Implementations
Sourceimpl HostFunctionPolicy
impl HostFunctionPolicy
Sourcepub fn allowing(
profile: impl Into<String>,
imports: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn allowing( profile: impl Into<String>, imports: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Returns a profile with an explicit allowlist of host imports.
Sourcepub fn evaluate(&self, target: &ModuleTargetDescriptor) -> HostImportReport
pub fn evaluate(&self, target: &ModuleTargetDescriptor) -> HostImportReport
Evaluates a target’s requested host imports against this policy.
Rejects a target before execution when required host imports are unavailable.