ResolveError

Enum ResolveError 

pub enum ResolveError {
    ArtifactNotFound {
        artifact_id: String,
    },
    ArtifactHashMismatch {
        expected: String,
        actual: String,
    },
    SchemaIdMismatch {
        expected: String,
        actual: String,
    },
    OperationIdMismatch {
        expected: String,
        actual: String,
    },
    RequirementsDigestMismatch {
        expected: String,
        actual: String,
    },
}
Error raised when an optic artifact reference cannot resolve cleanly.

Variants



ArtifactNotFound

No artifact exists for the referenced artifact identity.

Fields

artifact_id: String

Artifact identity requested by the descriptor.



ArtifactHashMismatch

The supplied artifact hash does not match the stored artifact.

Fields

expected: String

Artifact hash expected by the stored artifact.

actual: String

Artifact hash supplied by the caller.



SchemaIdMismatch

The supplied schema id does not match the stored artifact.

Fields

expected: String

Schema id expected by the stored artifact.

actual: String

Schema id supplied by the caller.



OperationIdMismatch

The supplied operation id does not match the stored artifact.

Fields

expected: String

Operation id expected by the stored artifact.

actual: String

Operation id supplied by the caller.



RequirementsDigestMismatch

The supplied requirements digest does not match the stored artifact.

Fields

expected: String

Requirements digest expected by the stored artifact.

actual: String

Requirements digest supplied by the caller.