pub enum ResolveError {
ArtifactNotFound {
artifact_id: String,
},
ArtifactHashMismatch {
expected: String,
actual: String,
},
SchemaIdMismatch {
expected: String,
actual: String,
},
OperationIdMismatch {
expected: String,
actual: String,
},
RequirementsDigestMismatch {
expected: String,
actual: String,
},
}Expand description
Error raised when an optic artifact reference cannot resolve cleanly.
Variants
ArtifactNotFound
No artifact exists for the referenced artifact identity.
ArtifactHashMismatch
The supplied artifact hash does not match the stored artifact.
Fields
SchemaIdMismatch
The supplied schema id does not match the stored artifact.
Fields
OperationIdMismatch
The supplied operation id does not match the stored artifact.
Fields
RequirementsDigestMismatch
The supplied requirements digest does not match the stored artifact.